@@ -801,6 +801,8 @@ void createSharedObjects(void) {
 }
 
 void initServerConfig() {
+    getRandomHexChars(server.runid,REDIS_RUN_ID_SIZE);
+    server.runid[REDIS_RUN_ID_SIZE] = '\0';
     server.arch_bits = (sizeof(long) == 8) ? 64 : 32;
     server.port = REDIS_SERVERPORT;
     server.bindaddr = NULL;
@@ -875,6 +877,7 @@ void initServerConfig() {
     server.repl_syncio_timeout = REDIS_REPL_SYNCIO_TIMEOUT;
     server.repl_serve_stale_data = 1;
     server.repl_down_since = time(NULL);
+    server.slave_priority = REDIS_DEFAULT_SLAVE_PRIORITY;
 
     /* Double constants initialization */
     R_Zero = 0.0;
@@ -1276,6 +1279,7 @@ sds genRedisInfoString(void) {
         "multiplexing_api:%s\r\n"
         "gcc_version:%d.%d.%d\r\n"
         "process_id:%ld\r\n"
+        "run_id:%s\r\n"
         "uptime_in_seconds:%ld\r\n"
         "uptime_in_days:%ld\r\n"
         "lru_clock:%ld\r\n"
@@ -1323,6 +1327,7 @@ sds genRedisInfoString(void) {
         0,0,0,
 #endif
         (long) getpid(),
+        server.runid,
         uptime,
         uptime/(3600*24),
         (unsigned long) server.lruclock,
@@ -1436,6 +1441,8 @@ sds genRedisInfoString(void) {
                 "master_link_down_since_seconds:%ld\r\n",
                 (long)time(NULL)-server.repl_down_since);
         }
+        info = sdscatprintf(info,
+            "slave_priority:%d\r\n", server.slave_priority);
     }
 
     if (server.vm_enabled) {
